pub struct PdfOptions {
pub ident: Smart<String>,
pub creator: Smart<Option<String>>,
pub timestamp: Option<Timestamp>,
pub page_ranges: Option<PageRanges>,
pub standards: PdfStandards,
pub tagged: bool,
pub pretty: bool,
}Expand description
Settings for PDF export.
Fields
ident: Smart<String>If not Smart::Auto, shall be a string that uniquely and stably
identifies the document. It should not change between compilations of
the same document. If you cannot provide such a stable identifier,
just pass Smart::Auto rather than trying to come up with one. The
CLI, for example, does not have a well-defined notion of a long-lived
project and as such just passes Smart::Auto.
If an ident is given, the hash of it will be used to create a PDF
document identifier (the identifier itself is not leaked). If ident is
Auto, a hash of the document’s title and author is used instead (which
is reasonably unique and stable).
creator: Smart<Option<String>>Configures the /Creator metadata in the resulting PDF. When set to
Smart::Auto, defaults to Typst $version.
timestamp: Option<Timestamp>If not None, shall be the creation timestamp of the document. It will
only be used if set document(date: ..) is auto.
page_ranges: Option<PageRanges>Specifies which ranges of pages should be exported in the PDF. When
None, all pages should be exported.
standards: PdfStandardsA list of PDF standards that Typst will enforce conformance with.
tagged: boolBy default, even when not producing a PDF/UA-1 document, a tagged PDF
document is written to provide a baseline of accessibility. In some
circumstances, for example when trying to reduce the size of a document,
it can be desirable to disable tagged PDF.
pretty: boolWhether to format the PDF in a human-readable way.